==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-file-associations/translations/lxqt-config-file-associations_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Alkalmazás választó</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Válassz alkalmazást ehhez:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>JPEG kezelő alkalmazás</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>ÚJ alelem</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Más alkalmazás</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>A %1 alkalmazásai</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Nincs alkalmazás</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Változtat...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Választás...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Fájlhozzárendelések</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Alapértelmezett alkalmazás</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Választás...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Felirat</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Szűrők</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME típus</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.15.0.orig.tar.xz: lxqt-config-0.15.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Alkalmazás választó</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Válassz alkalmazást ehhez:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>JPEG kezelő alkalmazás</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Új alelem</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Más alkalmazás</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>A %1 alkalmazásai</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Nincs alkalmazás</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Változtat...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Választás...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Fájlhozzárendelések</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Alapértelmezett alkalmazás</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Választás...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Felirat</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Szűrők</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME típus</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
</context>
</TS>
